Options ls=256 ps=100 nodate pageno=1 NOCENTER;
Data meta0;
length Soiltype$ 40 Design$ 20;
infile 'C:\Meta-analysis(no outlier).csv' 
dlm=',' firstobs=2;
input Data Study EN yield1 yield2 SEM1 SDE SEM2 SDC N1 N2 DFerror Design$ Type$ Species$ Nitro NitroCV$ Years Killdate KillCV$ Soiltype$ Tillage$ State$ Region$ BioOrGrain$ Temp$;
label yield1=control yield2=exp SEM1=exp SEM2=control N1=control N2=exp Temp=(C/Year);
RR=yield2/yield1;
L=log(RR);
VE=(SEM1**2)*N1;
VE1=SDE**2;
VA=(SEM2**2)*N1;
VA1=SDC**2;
YESQ=YIELD1**2;
YASQ=YIELD2**2;
E=1/(N1*YESQ);
A=1/(N2*YASQ);
V=(VE*E)+(VA*A);
V1=(VE1*E)+(VA1*A);
W=1/V;
W1=1/V1;
LSQ=L**2;
WLSQ=W1*LSQ; 
WSQ=W1**2;
WL=L*W1;
WSTAR=1/( V1 +    0.016488);
*WSTAR1=1/( V +   .008832986);
WLSTAR=L*WSTAR;
WSTARLSQ=WSTAR*LSQ;
*if region='GP' then L=.;
run;

PROC PRINT data=meta0; RUN;

proc sort data=Meta0; by design;
proc means data=Meta0 n noprint; by design;var L;
output out=design n=desn; proc print data=design;
run;

/*LEGUME*/
data Legume;
set meta0;
if Type ^='Legume' then delete;
run; proc print data=Legume; var EN; run;

TITLE 'WEIGHTED TOTAL SUMS OF SQUARES';
proc mixed data=Legume method=type3; weight W1;
model L=  / chisq;
ods output type3=SumsS;
run;

data test;
set SumsS;
Qprob=1-probchi(SS, DF);
run;
proc print data=test; var Source DF SS Qprob; run;

TITLE 'CALCULATING SUMMARY STATISTICS FOR L';
Proc means DATA=Legume sum mean n ;
var V1 WL W1 WLSQ WSQ L LSQ ;
OUTPUT OUT=COMBINE sum=SV SWL SW SWLSQ SWSQ SD SLSQ  
                  MEAN=MNV MNWD MNW MNWDSQ MNWSQ MND MNDSQ 
				  N = N1 N2 N3 N4 N5 N6 N7 ;PROC PRINT DATA=COMBINE;RUN;

TITLE 'CALCULATING THE VARIANCE BETWEEN STUDIES';
DATA VARBET;
MERGE combine sumss;
N=SS-DF;
CORRW=SWSQ/SW;
UNCORRW=SW;
D=UNCORRW-CORRW;
VAR=N/D;
proc print data=varbet; var var mnv ;
RUN;

/* MIXED MODEL*/
TITLE 'CALCULATING SUMMARY STATISTICS FOR LSTAR';
Proc means DATA=LEGUME sum mean n ;
var V1 WLSTAR WSTAR WSTARLSQ WSQ L LSQ ;
OUTPUT OUT=COMBINE2 sum=SV SWLSTAR SWSTAR SWLSQ SWSQ SD SLSQ  
                  MEAN=MNV MNWD MNW MNWDSQ MNWSQ MND MNDSQ 
				  N = N1 N2 N3 N4 N5 N6 N7 ;PROC PRINT DATA=COMBINE2;RUN;

data combine; 
set combine2;
LBAR=SWLSTAR/SWSTAR; 
STANDERR=SQRT (1/SWSTAR);
DLOWBND=LBAR-(1.96*(STANDERR));
DUPPBND=LBAR+(1.96*(STANDERR));
ZTEST=(ABS(LBAR))/STANDERR;
ZPROB=2*(1-(PROBNORM(ZTEST)));
Q=SWLSQ-((SWLSTAR**2)/SWSTAR);
POFQ = 1-PROBCHI(Q,N1-1);
S2D=(1/(N1-1))*((SLSQ)-((SD**2)/N1));
SIG2DELT=S2D-MNV;
*QVARC=SUMQVC3-((SUMQVC1**2)/SUMQVC2);
*POFQVC=1-PROBCHI(QVARC, N1-1);
*C=(SW-((SWSQ/SW)));
*VARCOMP2=(Q-(N1-1))/C;
proc print;
Title 'COMBINING RESPONSE RATIOS';
VAR LBAR STANDERR DLOWBND DUPPBND ZTEST ZPROB Q POFQ;
RUN;

TITLE 'TILLAGE';
proc mixed data=Legume method=type3; weight WSTAR;
class Tillage;
model L= Tillage ;
ods output type3=SumsS3;
lsmeans tillage / cl;
run;

data test3;
set SumsS3;
Qprob=1-probchi(SS, DF);
run;
proc print data=test3; var Source DF SS Qprob; run;

TITLE 'KILLDATE';
proc mixed data=Legume method=type3; weight WSTAR;
class KILLCV;
model L= KILLCV ;
ods output type3=SumsS5;
lsmeans killcv /cl;
run;

data test5;
set SumsS5;
Qprob=1-probchi(SS, DF);
run;
proc print data=test5; var Source DF SS Qprob; run;

TITLE 'NITRO';
proc mixed data=Legume method=type3; weight WSTAR;
class NitroCV;
model L= NitroCV ;
ods output type3=SumsS4;
lsmeans nitroCV /cl;
run;

data test4;
set SumsS4;
Qprob=1-probchi(SS, DF);
run;
proc print data=test4; var Source DF SS Qprob; run;

TITLE 'GRAINORBIO';
proc mixed data=Legume method=type3; weight WSTAR;
class BIOORGRAIN;
model L= BIOORGRAIN ;
ods output type3=SumsS4;
lsmeans BIOORGRAIN /cl;
run;

data test4;
set SumsS4;
Qprob=1-probchi(SS, DF);
run;
proc print data=test4; var Source DF SS Qprob; run;

TITLE 'REGION';
proc mixed data=Legume method=type3; weight WSTAR;
class REGION;
model L= REGION ;
ods output type3=SumsS4;
lsmeans REGION /cl;
run;

data test4;
set SumsS4;
Qprob=1-probchi(SS, DF);
run;
proc print data=test4; var Source DF SS Qprob; run;

proc freq data=meta0;
tables region;
run;
